==> kubernetes-model-gatewayapi-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/GRPCRouteListFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class GRPCRouteListFluent<A extends GRPCRouteListFluent<A>> extends BaseFluent<A>{
  public GRPCRouteListFluent() {
  }
  public GRPCRouteListFluent(GRPCRouteList instance) {
    instance = (instance != null ? instance : new GRPCRouteList());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String apiVersion;
  private ArrayList<GRPCRouteBuilder> items = new ArrayList<GRPCRouteBuilder>();
  private String kind;
  private ListMeta metadata;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public A addToItems(int index,GRPCRoute item) {
    if (this.items == null) {this.items = new ArrayList<GRPCRouteBuilder>();}
    GRPCRouteBuilder builder = new GRPCRouteBuilder(item);
    if (index < 0 || index >= items.size()) { _visitables.get("items").add(builder); items.add(builder); } else { _visitables.get("items").add(index, builder); items.add(index, builder);}
    return (A)this;
  }
  public A setToItems(int index,GRPCRoute item) {
    if (this.items == null) {this.items = new ArrayList<GRPCRouteBuilder>();}
    GRPCRouteBuilder builder = new GRPCRouteBuilder(item);
    if (index < 0 || index >= items.size()) { _visitables.get("items").add(builder); items.add(builder); } else { _visitables.get("items").set(index, builder); items.set(index, builder);}
    return (A)this;
  }
  public A addToItems(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.GRPCRoute... items) {
    if (this.items == null) {this.items = new ArrayList<GRPCRouteBuilder>();}
    for (GRPCRoute item : items) {GRPCRouteBuilder builder = new GRPCRouteBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A addAllToItems(Collection<GRPCRoute> items) {
    if (this.items == null) {this.items = new ArrayList<GRPCRouteBuilder>();}
    for (GRPCRoute item : items) {GRPCRouteBuilder builder = new GRPCRouteBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A removeFromItems(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.GRPCRoute... items) {
    if (this.items == null) return (A)this;
    for (GRPCRoute item : items) {GRPCRouteBuilder builder = new GRPCRouteBuilder(item);_visitables.get("items").remove(builder); this.items.remove(builder);} return (A)this;
  }
  public A removeAllFromItems(Collection<GRPCRoute> items) {
    if (this.items == null) return (A)this;
    for (GRPCRoute item : items) {GRPCRouteBuilder builder = new GRPCRouteBuilder(item);_visitables.get("items").remove(builder); this.items.remove(builder);} return (A)this;
  }
  public A removeMatchingFromItems(Predicate<GRPCRouteBuilder> predicate) {
    if (items == null) return (A) this;
    final Iterator<GRPCRouteBuilder> each = items.iterator();
    final List visitables = _visitables.get("items");
    while (each.hasNext()) {
      GRPCRouteBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  public List<GRPCRoute> buildItems() {
    return items != null ? build(items) : null;
  }
  public GRPCRoute buildItem(int index) {
    return this.items.get(index).build();
  }
  public GRPCRoute buildFirstItem() {
    return this.items.get(0).build();
  }
  public GRPCRoute buildLastItem() {
    return this.items.get(items.size() - 1).build();
  }
  public GRPCRoute buildMatchingItem(Predicate<GRPCRouteBuilder> predicate) {
    for (GRPCRouteBuilder item: items) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public boolean hasMatchingItem(Predicate<GRPCRouteBuilder> predicate) {
    for (GRPCRouteBuilder item: items) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withItems(List<GRPCRoute> items) {
    if (this.items != null) { _visitables.get("items").clear();}
    if (items != null) {this.items = new ArrayList(); for (GRPCRoute item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
  }
  public A withItems(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.GRPCRoute... items) {
    if (this.items != null) {this.items.clear(); _visitables.remove("items"); }
    if (items != null) {for (GRPCRoute item :items){ this.addToItems(item);}} return (A) this;
  }
  public boolean hasItems() {
    return items != null && !items.isEmpty();
  }
  public ItemsNested<A> addNewItem() {
    return new ItemsNested(-1, null);
  }
  public ItemsNested<A> addNewItemLike(GRPCRoute item) {
    return new ItemsNested(-1, item);
  }
  public ItemsNested<A> setNewItemLike(int index,GRPCRoute item) {
    return new ItemsNested(index, item);
  }
  public ItemsNested<A> editItem(int index) {
    if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
    return setNewItemLike(index, buildItem(index));
  }
  public ItemsNested<A> editFirstItem() {
    if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
    return setNewItemLike(0, buildItem(0));
  }
  public ItemsNested<A> editLastItem() {
    int index = items.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
    return setNewItemLike(index, buildItem(index));
  }
  public ItemsNested<A> editMatchingItem(Predicate<GRPCRouteBuilder> predicate) {
    int index = -1;
    for (int i=0;i<items.size();i++) { 
    if (predicate.test(items.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
    return setNewItemLike(index, buildItem(index));
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public boolean hasKind() {
    return this.kind != null;
  }
  public ListMeta getMetadata() {
    return this.metadata;
  }
  public A withMetadata(ListMeta metadata) {
    this.metadata=metadata; return (A) this;
  }
  public boolean hasMetadata() {
    return this.metadata != null;
  }
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink) {
    return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GRPCRouteListFluent that = (GRPCRouteListFluent) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(items, that.items)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (items != null && !items.isEmpty()) { sb.append("items:"); sb.append(items + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ItemsNested<N> extends GRPCRouteFluent<ItemsNested<N>> implements Nested<N>{
    ItemsNested(int index,GRPCRoute item) {
      this.index = index;
      this.builder = new GRPCRouteBuilder(this, item);
    }
    GRPCRouteBuilder builder;
    int index;
    public N and() {
      return (N) GRPCRouteListFluent.this.setToItems(index,builder.build());
    }
    public N endItem() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-gatewayapi-6.9.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/GRPCRouteListFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class GRPCRouteListFluent<A extends GRPCRouteListFluent<A>> extends BaseFluent<A>{
  public GRPCRouteListFluent() {
  }
  
  public GRPCRouteListFluent(GRPCRouteList instance) {
    this.copyInstance(instance);
  }
  private String apiVersion;
  private ArrayList<GRPCRouteBuilder> items = new ArrayList<GRPCRouteBuilder>();
  private String kind;
  private ListMeta metadata;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(GRPCRouteList instance) {
    instance = (instance != null ? instance : new GRPCRouteList());
  
    if (instance != null) {
        this.withApiVersion(instance.getApiVersion());
        this.withItems(instance.getItems());
        this.withKind(instance.getKind());
        this.withMetadata(instance.getMetadata());
        this.withApiVersion(instance.getApiVersion());
        this.withItems(instance.getItems());
        this.withKind(instance.getKind());
        this.withMetadata(instance.getMetadata());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getApiVersion() {
    return this.apiVersion;
  }
  
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  
  public boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  public A addToItems(int index,GRPCRoute item) {
    if (this.items == null) {this.items = new ArrayList<GRPCRouteBuilder>();}
    GRPCRouteBuilder builder = new GRPCRouteBuilder(item);
    if (index < 0 || index >= items.size()) { _visitables.get("items").add(builder); items.add(builder); } else { _visitables.get("items").add(index, builder); items.add(index, builder);}
    return (A)this;
  }
  
  public A setToItems(int index,GRPCRoute item) {
    if (this.items == null) {this.items = new ArrayList<GRPCRouteBuilder>();}
    GRPCRouteBuilder builder = new GRPCRouteBuilder(item);
    if (index < 0 || index >= items.size()) { _visitables.get("items").add(builder); items.add(builder); } else { _visitables.get("items").set(index, builder); items.set(index, builder);}
    return (A)this;
  }
  
  public A addToItems(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.GRPCRoute... items) {
    if (this.items == null) {this.items = new ArrayList<GRPCRouteBuilder>();}
    for (GRPCRoute item : items) {GRPCRouteBuilder builder = new GRPCRouteBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  
  public A addAllToItems(Collection<GRPCRoute> items) {
    if (this.items == null) {this.items = new ArrayList<GRPCRouteBuilder>();}
    for (GRPCRoute item : items) {GRPCRouteBuilder builder = new GRPCRouteBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  
  public A removeFromItems(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.GRPCRoute... items) {
    if (this.items == null) return (A)this;
    for (GRPCRoute item : items) {GRPCRouteBuilder builder = new GRPCRouteBuilder(item);_visitables.get("items").remove(builder); this.items.remove(builder);} return (A)this;
  }
  
  public A removeAllFromItems(Collection<GRPCRoute> items) {
    if (this.items == null) return (A)this;
    for (GRPCRoute item : items) {GRPCRouteBuilder builder = new GRPCRouteBuilder(item);_visitables.get("items").remove(builder); this.items.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromItems(Predicate<GRPCRouteBuilder> predicate) {
    if (items == null) return (A) this;
    final Iterator<GRPCRouteBuilder> each = items.iterator();
    final List visitables = _visitables.get("items");
    while (each.hasNext()) {
      GRPCRouteBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<GRPCRoute> buildItems() {
    return items != null ? build(items) : null;
  }
  
  public GRPCRoute buildItem(int index) {
    return this.items.get(index).build();
  }
  
  public GRPCRoute buildFirstItem() {
    return this.items.get(0).build();
  }
  
  public GRPCRoute buildLastItem() {
    return this.items.get(items.size() - 1).build();
  }
  
  public GRPCRoute buildMatchingItem(Predicate<GRPCRouteBuilder> predicate) {
    for (GRPCRouteBuilder item: items) { if(predicate.test(item)){ return item.build();} } return null;
  }
  
  public boolean hasMatchingItem(Predicate<GRPCRouteBuilder> predicate) {
    for (GRPCRouteBuilder item: items) { if(predicate.test(item)){ return true;} } return false;
  }
  
  public A withItems(List<GRPCRoute> items) {
    if (this.items != null) { _visitables.get("items").clear();}
    if (items != null) {this.items = new ArrayList(); for (GRPCRoute item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
  }
  
  public A withItems(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.GRPCRoute... items) {
    if (this.items != null) {this.items.clear(); _visitables.remove("items"); }
    if (items != null) {for (GRPCRoute item :items){ this.addToItems(item);}} return (A) this;
  }
  
  public boolean hasItems() {
    return items != null && !items.isEmpty();
  }
  
  public ItemsNested<A> addNewItem() {
    return new ItemsNested(-1, null);
  }
  
  public ItemsNested<A> addNewItemLike(GRPCRoute item) {
    return new ItemsNested(-1, item);
  }
  
  public ItemsNested<A> setNewItemLike(int index,GRPCRoute item) {
    return new ItemsNested(index, item);
  }
  
  public ItemsNested<A> editItem(int index) {
    if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
    return setNewItemLike(index, buildItem(index));
  }
  
  public ItemsNested<A> editFirstItem() {
    if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
    return setNewItemLike(0, buildItem(0));
  }
  
  public ItemsNested<A> editLastItem() {
    int index = items.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
    return setNewItemLike(index, buildItem(index));
  }
  
  public ItemsNested<A> editMatchingItem(Predicate<GRPCRouteBuilder> predicate) {
    int index = -1;
    for (int i=0;i<items.size();i++) { 
    if (predicate.test(items.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
    return setNewItemLike(index, buildItem(index));
  }
  
  public String getKind() {
    return this.kind;
  }
  
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  
  public boolean hasKind() {
    return this.kind != null;
  }
  
  public ListMeta getMetadata() {
    return this.metadata;
  }
  
  public A withMetadata(ListMeta metadata) {
    this.metadata=metadata; return (A) this;
  }
  
  public boolean hasMetadata() {
    return this.metadata != null;
  }
  
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink) {
    return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GRPCRouteListFluent that = (GRPCRouteListFluent) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;
  
    if (!java.util.Objects.equals(items, that.items)) return false;
  
    if (!java.util.Objects.equals(kind, that.kind)) return false;
  
    if (!java.util.Objects.equals(metadata, that.metadata)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (items != null && !items.isEmpty()) { sb.append("items:"); sb.append(items + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ItemsNested<N> extends GRPCRouteFluent<ItemsNested<N>> implements Nested<N>{
    ItemsNested(int index,GRPCRoute item) {
      this.index = index;
      this.builder = new GRPCRouteBuilder(this, item);
    }
    GRPCRouteBuilder builder;
    int index;
    
    public N and() {
      return (N) GRPCRouteListFluent.this.setToItems(index,builder.build());
    }
    
    public N endItem() {
      return and();
    }
    
  
  }

}
